@@ -22,4 +22,6 @@ def login():
 @app.get('/logout')
 def logout():
     '''Simply deletes the account cookie, effectively logging the sensor out.'''
-    response.delete_cookie('user')
\ No newline at end of file
+    response.delete_cookie('user',
+        secret=setting('cookie_key').value
+    )
\ No newline at end of file
